pyargcbr.agents package
=======================

Submodules
----------

pyargcbr.agents.arg\_message module
-----------------------------------

.. automodule:: pyargcbr.agents.arg_message
    :members:
    :undoc-members:
    :show-inheritance:

pyargcbr.agents.argumentation\_agent module
-------------------------------------------

.. automodule:: pyargcbr.agents.argumentation_agent
    :members:
    :undoc-members:
    :show-inheritance:

pyargcbr.agents.commitment\_store\_agent module
-----------------------------------------------

.. automodule:: pyargcbr.agents.commitment_store_agent
    :members:
    :undoc-members:
    :show-inheritance:

pyargcbr.agents.configuration module
------------------------------------

.. automodule:: pyargcbr.agents.configuration
    :members:
    :undoc-members:
    :show-inheritance:

pyargcbr.agents.debug\_agent module
-----------------------------------

.. automodule:: pyargcbr.agents.debug_agent
    :members:
    :undoc-members:
    :show-inheritance:

pyargcbr.agents.metrics module
------------------------------

.. automodule:: pyargcbr.agents.metrics
    :members:
    :undoc-members:
    :show-inheritance:

pyargcbr.agents.protocol module
-------------------------------

.. automodule:: pyargcbr.agents.protocol
    :members:
    :undoc-members:
    :show-inheritance:

pyargcbr.agents.similarity\_algorithms module
---------------------------------------------

.. automodule:: pyargcbr.agents.similarity_algorithms
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: pyargcbr.agents
    :members:
    :undoc-members:
    :show-inheritance:
